@@ -14,11 +14,11 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
+#include <config.h>
 #include "gconf-internals.h"
 #include "gconf-backend.h"
 #include "gconf-schema.h"
@@ -2465,7 +2465,7 @@ get_ior (gboolean start_if_not_found,
         if (dbus_error_is_set (&bus_error)) {
                 if (failure_log)
                     g_string_append_printf (failure_log,
-                                            _("Could not send message to gconf daemon: %s"),
+                                            _("Could not send message to GConf daemon: %s"),
                                             bus_error.message);
                 dbus_error_free (&bus_error);
                 return NULL;
@@ -2549,10 +2549,12 @@ gconf_get_lock_or_current_holder (const gchar  *lock_directory,
   if (g_mkdir (lock_directory, 0700) < 0 &&
       errno != EEXIST)
     {
+      int errsv = errno;
+
       gconf_set_error (err,
                        GCONF_ERROR_LOCK_FAILED,
                        _("couldn't create directory `%s': %s"),
-                       lock_directory, g_strerror (errno));
+                       lock_directory, g_strerror (errsv));
 
       return NULL;
     }
@@ -2880,7 +2882,7 @@ gconf_activate_server (gboolean  start_if_not_found,
     g_set_error (error,
                  GCONF_ERROR,
                  GCONF_ERROR_NO_SERVER,
-                 _("Failed to contact configuration server; some possible causes are that you need to enable TCP/IP networking for ORBit, or you have stale NFS locks due to a system crash. See http://www.gnome.org/projects/gconf/ for information. (Details - %s)"),
+                 _("Failed to contact configuration server; some possible causes are that you need to enable TCP/IP networking for ORBit, or you have stale NFS locks due to a system crash. See http://projects.gnome.org/gconf/ for information. (Details - %s)"),
                  failure_log->len > 0 ? failure_log->str : _("none"));
 
   g_string_free (failure_log, TRUE);
